CreateInstanceFluentBuilder

Struct CreateInstanceFluentBuilder 

pub struct CreateInstanceFluentBuilder { /* private fields */ }
Fluent builder constructing a request to CreateInstance.

Enables you to programmatically create an Amazon Web Services Supply Chain instance by applying KMS keys and relevant information associated with the API without using the Amazon Web Services console.

This is an asynchronous operation. Upon receiving a CreateInstance request, Amazon Web Services Supply Chain immediately returns the instance resource, instance ID, and the initializing state while simultaneously creating all required Amazon Web Services resources for an instance creation. You can use GetInstance to check the status of the instance. If the instance results in an unhealthy state, you need to check the error message, delete the current instance, and recreate a new one based on the mitigation from the error message.

Implementations

Source

impl CreateInstanceFluentBuilder

pub fn as_input(&self) -> &CreateInstanceInputBuilder

Access the CreateInstance as a reference.

pub async fn send( self, ) -> Result<CreateInstanceOutput, SdkError<CreateInstanceError, HttpResponse>>

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

pub fn customize( self, ) -> CustomizableOperation<CreateInstanceOutput, CreateInstanceError, Self>

Consumes this builder, creating a customizable operation that can be modified before being sent.

pub fn instance_name(self, input: impl Into<String>) -> Self

The AWS Supply Chain instance name.

pub fn set_instance_name(self, input: Option<String>) -> Self

The AWS Supply Chain instance name.

pub fn get_instance_name(&self) -> &Option<String>

The AWS Supply Chain instance name.

pub fn instance_description(self, input: impl Into<String>) -> Self

The AWS Supply Chain instance description.

pub fn set_instance_description(self, input: Option<String>) -> Self

The AWS Supply Chain instance description.

pub fn get_instance_description(&self) -> &Option<String>

The AWS Supply Chain instance description.

pub fn kms_key_arn(self, input: impl Into<String>) -> Self

The ARN (Amazon Resource Name) of the Key Management Service (KMS) key you provide for encryption. This is required if you do not want to use the Amazon Web Services owned KMS key. If you don't provide anything here, AWS Supply Chain uses the Amazon Web Services owned KMS key.

pub fn set_kms_key_arn(self, input: Option<String>) -> Self

The ARN (Amazon Resource Name) of the Key Management Service (KMS) key you provide for encryption. This is required if you do not want to use the Amazon Web Services owned KMS key. If you don't provide anything here, AWS Supply Chain uses the Amazon Web Services owned KMS key.

pub fn get_kms_key_arn(&self) -> &Option<String>

The ARN (Amazon Resource Name) of the Key Management Service (KMS) key you provide for encryption. This is required if you do not want to use the Amazon Web Services owned KMS key. If you don't provide anything here, AWS Supply Chain uses the Amazon Web Services owned KMS key.

pub fn web_app_dns_domain(self, input: impl Into<String>) -> Self

The DNS subdomain of the web app. This would be "example" in the URL "example.scn.global.on.aws". You can set this to a custom value, as long as the domain isn't already being used by someone else. The name may only include alphanumeric characters and hyphens.

pub fn set_web_app_dns_domain(self, input: Option<String>) -> Self

The DNS subdomain of the web app. This would be "example" in the URL "example.scn.global.on.aws". You can set this to a custom value, as long as the domain isn't already being used by someone else. The name may only include alphanumeric characters and hyphens.

pub fn get_web_app_dns_domain(&self) -> &Option<String>

The DNS subdomain of the web app. This would be "example" in the URL "example.scn.global.on.aws". You can set this to a custom value, as long as the domain isn't already being used by someone else. The name may only include alphanumeric characters and hyphens.

pub fn tags(self, k: impl Into<String>, v: impl Into<String>) -> Self

Adds a key-value pair to tags.

To override the contents of this collection use set_tags.

The Amazon Web Services tags of an instance to be created.

pub fn set_tags(self, input: Option<HashMap<String, String>>) -> Self

The Amazon Web Services tags of an instance to be created.

pub fn get_tags(&self) -> &Option<HashMap<String, String>>

The Amazon Web Services tags of an instance to be created.

pub fn client_token(self, input: impl Into<String>) -> Self

The client token for idempotency.

pub fn set_client_token(self, input: Option<String>) -> Self

The client token for idempotency.

pub fn get_client_token(&self) -> &Option<String>

The client token for idempotency.