#[non_exhaustive]pub struct CreateInstanceInputBuilder { /* private fields */ }Expand description
A builder for CreateInstanceInput.
Implementations
Sourceimpl CreateInstanceInputBuilder
impl CreateInstanceInputBuilder
Sourcepub fn instance_name(self, input: impl Into<String>) -> Self
pub fn instance_name(self, input: impl Into<String>) -> Self
The AWS Supply Chain instance name.
Sourcepub fn set_instance_name(self, input: Option<String>) -> Self
pub fn set_instance_name(self, input: Option<String>) -> Self
The AWS Supply Chain instance name.
Sourcepub fn get_instance_name(&self) -> &Option<String>
pub fn get_instance_name(&self) -> &Option<String>
The AWS Supply Chain instance name.
Sourcepub fn instance_description(self, input: impl Into<String>) -> Self
pub fn instance_description(self, input: impl Into<String>) -> Self
The AWS Supply Chain instance description.
Sourcepub fn set_instance_description(self, input: Option<String>) -> Self
pub fn set_instance_description(self, input: Option<String>) -> Self
The AWS Supply Chain instance description.
Sourcepub fn get_instance_description(&self) -> &Option<String>
pub fn get_instance_description(&self) -> &Option<String>
The AWS Supply Chain instance description.
Sourcepub fn kms_key_arn(self, input: impl Into<String>) -> Self
pub fn kms_key_arn(self, input: impl Into<String>) -> Self
The ARN (Amazon Resource Name) of the Key Management Service (KMS) key you provide for encryption. This is required if you do not want to use the Amazon Web Services owned KMS key. If you don't provide anything here, AWS Supply Chain uses the Amazon Web Services owned KMS key.
Sourcepub fn set_kms_key_arn(self, input: Option<String>) -> Self
pub fn set_kms_key_arn(self, input: Option<String>) -> Self
The ARN (Amazon Resource Name) of the Key Management Service (KMS) key you provide for encryption. This is required if you do not want to use the Amazon Web Services owned KMS key. If you don't provide anything here, AWS Supply Chain uses the Amazon Web Services owned KMS key.
Sourcepub fn get_kms_key_arn(&self) -> &Option<String>
pub fn get_kms_key_arn(&self) -> &Option<String>
The ARN (Amazon Resource Name) of the Key Management Service (KMS) key you provide for encryption. This is required if you do not want to use the Amazon Web Services owned KMS key. If you don't provide anything here, AWS Supply Chain uses the Amazon Web Services owned KMS key.
Sourcepub fn web_app_dns_domain(self, input: impl Into<String>) -> Self
pub fn web_app_dns_domain(self, input: impl Into<String>) -> Self
The DNS subdomain of the web app. This would be "example" in the URL "example.scn.global.on.aws". You can set this to a custom value, as long as the domain isn't already being used by someone else. The name may only include alphanumeric characters and hyphens.
Sourcepub fn set_web_app_dns_domain(self, input: Option<String>) -> Self
pub fn set_web_app_dns_domain(self, input: Option<String>) -> Self
The DNS subdomain of the web app. This would be "example" in the URL "example.scn.global.on.aws". You can set this to a custom value, as long as the domain isn't already being used by someone else. The name may only include alphanumeric characters and hyphens.
Sourcepub fn get_web_app_dns_domain(&self) -> &Option<String>
pub fn get_web_app_dns_domain(&self) -> &Option<String>
The DNS subdomain of the web app. This would be "example" in the URL "example.scn.global.on.aws". You can set this to a custom value, as long as the domain isn't already being used by someone else. The name may only include alphanumeric characters and hyphens.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
The Amazon Web Services tags of an instance to be created.
The Amazon Web Services tags of an instance to be created.
The Amazon Web Services tags of an instance to be created.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
The client token for idempotency.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
The client token for idempotency.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
The client token for idempotency.
Sourcepub fn build(self) -> Result<CreateInstanceInput, BuildError>
pub fn build(self) -> Result<CreateInstanceInput, BuildError>
Consumes the builder and constructs a CreateInstanceInput.
Sourceimpl CreateInstanceInputBuilder
impl CreateInstanceInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateInstanceOutput, SdkError<CreateInstanceError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateInstanceOutput, SdkError<CreateInstanceError, HttpResponse>>
Sends a request with this input using the given client.