#[non_exhaustive]pub struct UpdateDataIntegrationFlowInput {
pub instance_id: Option<String>,
pub name: Option<String>,
pub sources: Option<Vec<DataIntegrationFlowSource>>,
pub transformation: Option<DataIntegrationFlowTransformation>,
pub target: Option<DataIntegrationFlowTarget>,
}Expand description
The request parameters for UpdateDataIntegrationFlow.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.instance_id: Option<String>The Amazon Web Services Supply Chain instance identifier.
name: Option<String>The name of the DataIntegrationFlow to be updated.
sources: Option<Vec<DataIntegrationFlowSource>>The new source configurations for the DataIntegrationFlow.
transformation: Option<DataIntegrationFlowTransformation>The new transformation configurations for the DataIntegrationFlow.
target: Option<DataIntegrationFlowTarget>The new target configurations for the DataIntegrationFlow.
Implementations
Sourceimpl UpdateDataIntegrationFlowInput
impl UpdateDataIntegrationFlowInput
Sourcepub fn instance_id(&self) -> Option<&str>
pub fn instance_id(&self) -> Option<&str>
The Amazon Web Services Supply Chain instance identifier.
Sourcepub fn sources(&self) -> &[DataIntegrationFlowSource]
pub fn sources(&self) -> &[DataIntegrationFlowSource]
The new source configurations for the DataIntegrationFlow.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .sources.is_none().
Sourcepub fn transformation(&self) -> Option<&DataIntegrationFlowTransformation>
pub fn transformation(&self) -> Option<&DataIntegrationFlowTransformation>
The new transformation configurations for the DataIntegrationFlow.
Sourcepub fn target(&self) -> Option<&DataIntegrationFlowTarget>
pub fn target(&self) -> Option<&DataIntegrationFlowTarget>
The new target configurations for the DataIntegrationFlow.
Sourceimpl UpdateDataIntegrationFlowInput
impl UpdateDataIntegrationFlowInput
Sourcepub fn builder() -> UpdateDataIntegrationFlowInputBuilder
pub fn builder() -> UpdateDataIntegrationFlowInputBuilder
Creates a new builder-style object to manufacture UpdateDataIntegrationFlowInput.