#[non_exhaustive]pub struct DataIntegrationEventDatasetTargetDetails {
pub dataset_identifier: String,
pub operation_type: DataIntegrationEventDatasetOperationType,
pub dataset_load_execution: Option<DataIntegrationEventDatasetLoadExecutionDetails>,
}Expand description
The target dataset details for a DATASET event type.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.dataset_identifier: StringThe datalake dataset ARN identifier.
operation_type: DataIntegrationEventDatasetOperationTypeThe target dataset load operation type. The available options are:
-
APPEND - Add new records to the dataset. Noted that this operation type will just try to append records as-is without any primary key or partition constraints.
-
UPSERT - Modify existing records in the dataset with primary key configured, events for datasets without primary keys are not allowed. If event data contains primary keys that match records in the dataset within same partition, then those existing records (in that partition) will be updated. If primary keys do not match, new records will be added. Note that if dataset contain records with duplicate primary key values in the same partition, those duplicate records will be deduped into one updated record.
-
DELETE - Remove existing records in the dataset with primary key configured, events for datasets without primary keys are not allowed. If event data contains primary keys that match records in the dataset within same partition, then those existing records (in that partition) will be deleted. If primary keys do not match, no actions will be done. Note that if dataset contain records with duplicate primary key values in the same partition, all those duplicates will be removed.
dataset_load_execution: Option<DataIntegrationEventDatasetLoadExecutionDetails>The target dataset load execution.
Implementations
Sourceimpl DataIntegrationEventDatasetTargetDetails
impl DataIntegrationEventDatasetTargetDetails
Sourcepub fn dataset_identifier(&self) -> &str
pub fn dataset_identifier(&self) -> &str
The datalake dataset ARN identifier.
Sourcepub fn operation_type(&self) -> &DataIntegrationEventDatasetOperationType
pub fn operation_type(&self) -> &DataIntegrationEventDatasetOperationType
The target dataset load operation type. The available options are:
-
APPEND - Add new records to the dataset. Noted that this operation type will just try to append records as-is without any primary key or partition constraints.
-
UPSERT - Modify existing records in the dataset with primary key configured, events for datasets without primary keys are not allowed. If event data contains primary keys that match records in the dataset within same partition, then those existing records (in that partition) will be updated. If primary keys do not match, new records will be added. Note that if dataset contain records with duplicate primary key values in the same partition, those duplicate records will be deduped into one updated record.
-
DELETE - Remove existing records in the dataset with primary key configured, events for datasets without primary keys are not allowed. If event data contains primary keys that match records in the dataset within same partition, then those existing records (in that partition) will be deleted. If primary keys do not match, no actions will be done. Note that if dataset contain records with duplicate primary key values in the same partition, all those duplicates will be removed.
Sourcepub fn dataset_load_execution(
&self,
) -> Option<&DataIntegrationEventDatasetLoadExecutionDetails>
pub fn dataset_load_execution( &self, ) -> Option<&DataIntegrationEventDatasetLoadExecutionDetails>
The target dataset load execution.
Sourceimpl DataIntegrationEventDatasetTargetDetails
impl DataIntegrationEventDatasetTargetDetails
Sourcepub fn builder() -> DataIntegrationEventDatasetTargetDetailsBuilder
pub fn builder() -> DataIntegrationEventDatasetTargetDetailsBuilder
Creates a new builder-style object to manufacture DataIntegrationEventDatasetTargetDetails.