#[non_exhaustive]pub struct DataIntegrationFlowDatasetOptions {
pub load_type: Option<DataIntegrationFlowLoadType>,
pub dedupe_records: Option<bool>,
pub dedupe_strategy: Option<DataIntegrationFlowDedupeStrategy>,
}Expand description
The dataset options used in dataset source and target configurations.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.load_type: Option<DataIntegrationFlowLoadType>The target dataset's data load type. This only affects how source S3 files are selected in the S3-to-dataset flow.
-
REPLACE - Target dataset will get replaced with the new file added under the source s3 prefix.
-
INCREMENTAL - Target dataset will get updated with the up-to-date content under S3 prefix incorporating any file additions or removals there.
dedupe_records: Option<bool>The option to perform deduplication on data records sharing same primary key values. If disabled, transformed data with duplicate primary key values will ingest into dataset, for datasets within asc namespace, such duplicates will cause ingestion fail. If enabled without dedupeStrategy, deduplication is done by retaining a random data record among those sharing the same primary key values. If enabled with dedupeStragtegy, the deduplication is done following the strategy.
Note that target dataset may have partition configured, when dedupe is enabled, it only dedupe against primary keys and retain only one record out of those duplicates regardless of its partition status.
dedupe_strategy: Option<DataIntegrationFlowDedupeStrategy>The deduplication strategy to dedupe the data records sharing same primary key values of the target dataset. This strategy only applies to target dataset with primary keys and with dedupeRecords option enabled. If transformed data still got duplicates after the dedupeStrategy evaluation, a random data record is chosen to be retained.
Implementations
Sourceimpl DataIntegrationFlowDatasetOptions
impl DataIntegrationFlowDatasetOptions
Sourcepub fn load_type(&self) -> Option<&DataIntegrationFlowLoadType>
pub fn load_type(&self) -> Option<&DataIntegrationFlowLoadType>
The target dataset's data load type. This only affects how source S3 files are selected in the S3-to-dataset flow.
-
REPLACE - Target dataset will get replaced with the new file added under the source s3 prefix.
-
INCREMENTAL - Target dataset will get updated with the up-to-date content under S3 prefix incorporating any file additions or removals there.
Sourcepub fn dedupe_records(&self) -> Option<bool>
pub fn dedupe_records(&self) -> Option<bool>
The option to perform deduplication on data records sharing same primary key values. If disabled, transformed data with duplicate primary key values will ingest into dataset, for datasets within asc namespace, such duplicates will cause ingestion fail. If enabled without dedupeStrategy, deduplication is done by retaining a random data record among those sharing the same primary key values. If enabled with dedupeStragtegy, the deduplication is done following the strategy.
Note that target dataset may have partition configured, when dedupe is enabled, it only dedupe against primary keys and retain only one record out of those duplicates regardless of its partition status.
Sourcepub fn dedupe_strategy(&self) -> Option<&DataIntegrationFlowDedupeStrategy>
pub fn dedupe_strategy(&self) -> Option<&DataIntegrationFlowDedupeStrategy>
The deduplication strategy to dedupe the data records sharing same primary key values of the target dataset. This strategy only applies to target dataset with primary keys and with dedupeRecords option enabled. If transformed data still got duplicates after the dedupeStrategy evaluation, a random data record is chosen to be retained.
Sourceimpl DataIntegrationFlowDatasetOptions
impl DataIntegrationFlowDatasetOptions
Sourcepub fn builder() -> DataIntegrationFlowDatasetOptionsBuilder
pub fn builder() -> DataIntegrationFlowDatasetOptionsBuilder
Creates a new builder-style object to manufacture DataIntegrationFlowDatasetOptions.